summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp b/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
index 5507c314..6f6eb5ec 100644
--- a/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
+++ b/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
@@ -27,8 +27,8 @@
// Constructors/Destructors
//
-JavaCodeClassFieldDeclarationBlock::JavaCodeClassFieldDeclarationBlock ( CodeClassField * parent )
- : CodeClassFieldDeclarationBlock ( parent )
+JavaCodeClassFieldDeclarationBlock::JavaCodeClassFieldDeclarationBlock ( CodeClassField * tqparent )
+ : CodeClassFieldDeclarationBlock ( tqparent )
{
setOverallIndentationLevel(1);
updateContent();
@@ -67,7 +67,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
TQString scopeStr = jdoc->scopeToJavaDecl(getParentObject()->getVisibility());
// IF this is from an association, then scope taken as appropriate to policy
- if(!jcf->parentIsAttribute())
+ if(!jcf->tqparentIsAttribute())
{
switch (scopePolicy) {
case CodeGenerationPolicy::Public:
@@ -77,7 +77,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
break;
default:
case CodeGenerationPolicy::FromParent:
// do nothing here... will leave as from parent object
break;
}
}
@@ -86,13 +86,13 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
TQString fieldName = jcf->getFieldName();
TQString initialV = jcf->getInitialValue();
- if (!cf->parentIsAttribute() && !cf->fieldIsSingleValue())
+ if (!cf->tqparentIsAttribute() && !cf->fieldIsSingleValue())
typeName = "List";
TQString body = staticValue+scopeStr+' '+typeName+' '+fieldName;
if (!initialV.isEmpty())
body.append(" = " + initialV);
- else if (!cf->parentIsAttribute())
+ else if (!cf->tqparentIsAttribute())
{
UMLRole * role = dynamic_cast<UMLRole*>(cf->getParentObject());
if (role->getObject()->getBaseType() == Uml::ot_Interface)
@@ -101,7 +101,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
// of the parent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{
if(!typeName.isEmpty())
@@ -77,7 +77,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
default:
case CodeGenerationPolicy::FromParent:
- // do nothing here... will leave as from parent object
+ // do nothing here... will leave as from tqparent object
break;
}
@@ -101,7 +101,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
- // of the parent Object, then we can use that instead (if its empty).
+ // of the tqparent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{